@@ -1,10 +1,10 @@
-import logging
-
 import torch
 import torch.nn as nn
+import numpy as np
+from sklearn.preprocessing import MinMaxScaler
 
 
-def tensor_from_series(series, device, n_dims, pad_value, max_len):
+def tensor_from_series(series, device, n_dims, pad_value, max_len=None, normalizer=None):
     """
     :param series: list of lists, corresponds to time series: [[x1_1, ..., x1_n], [x2_1, ..., x2_n], ...]
                    the series is zero-padded on each axis so that all dimensions have equal length
@@ -15,28 +15,23 @@ def tensor_from_series(series, device, n_dims, pad_value, max_len):
     :return: series as a tensor ready for model consumption, shape (1, ts_length, n_dims)
     """
     # conversion to float
-    float_series = []
-    for dimn in series:
-        dimn_series = []
-        for ele in dimn:
-            try:
-                dimn_series.append(float(ele))
-            except Exception as _:
-                logging.warning(f'Weird element encountered in timeseries: {ele} !')
-                dimn_series.append(0)
-        float_series.append(dimn_series)
+    if max_len is None:
+        max_len = len(series[0]) if isinstance(series, list) else series.shape[1]
 
     # timestep padding and truncating
-    for i in range(len(float_series)):
-        for _ in range(max(0, max_len - len(float_series[i]))):
-            float_series[i].append(pad_value)
-        float_series[i] = float_series[i][:max_len]
+    for i in range(len(series)):
+        for _ in range(max(0, max_len - len(series[i]))):
+            series[i].append(pad_value)
+        series[i] = series[i][:max_len]
 
     # dimension padding
-    for _ in range(max(0, n_dims - len(float_series))):
-        float_series.append([pad_value] * max_len)
+    for _ in range(max(0, n_dims - len(series))):
+        series.append([pad_value] * max_len)
 
-    tensor = torch.transpose(torch.tensor(float_series, dtype=torch.float, device=device), 0, 1)
+    # normalize and transpose
+    if normalizer:
+        series = normalizer.transform(np.array(series))
+    tensor = torch.transpose(torch.tensor(series, dtype=torch.float, device=device), 0, 1)
 
     # add batch dimension
     return tensor.view(-1, max_len, n_dims)
@@ -78,3 +73,23 @@ class EncoderRNNNumerical(nn.Module):
 
     def initHidden(self, device):
         return torch.zeros(1, 1, self.hidden_size, device=device)
+
+
+class MinMaxNormalizer:
+    def __init__(self, factor=1):
+        self.scaler = MinMaxScaler()
+        self.factor = factor
+
+    def fit(self, x):
+        X = np.array([j for i in x for j in i]).reshape(-1, 1)
+        self.scaler.fit(X)
+
+    def transform(self, y):
+        return self.scaler.transform(y)
+
+    def fit_transform(self, x):
+        self.fit(x)
+        return self.transform(x)
+
+    def inverse_transform(self, y):
+        return self.scaler.inverse_transform(y)
