@@ -13,14 +13,12 @@ class DefaultNet(torch.nn.Module):
                      output_size=None,
                      nr_outputs=None,
                      shape=None,
-                     selfaware=False,
                      size_parameters={},
                      pretrained_net=None,
                      deterministic=False):
         self.input_size = input_size
         self.output_size = output_size
         self.nr_outputs = nr_outputs
-        self.selfaware = selfaware
         # How many devices we can train this network on
         self.available_devices = 1
         self.max_variance = None
@@ -73,21 +71,8 @@ class DefaultNet(torch.nn.Module):
                         self.input_size = layer.in_features
                     self.output_size = layer.out_features
 
-        if self.selfaware:
-            awareness_net_shape = [(self.input_size + self.output_size), max([int((self.input_size + self.output_size) * 1.5), 300]), self.nr_outputs]
-            awareness_layers = []
-
-
-            for ind in range(len(awareness_net_shape) - 1):
-                rectifier = torch.nn.SELU  #alternative: torch.nn.ReLU
-                awareness_layers.append(torch.nn.Linear(awareness_net_shape[ind], awareness_net_shape[ind + 1]))
-                if ind < len(awareness_net_shape) - 2:
-                    awareness_layers.append(rectifier())
-
-            self.awareness_net = torch.nn.Sequential(*awareness_layers)
-
         if deterministic and pretrained_net is None: # set initial weights based on a specific distribution if we have deterministic enabled
-            # lambda function so that we can do this for either awareness layer or the internal layers of net
+            # lambda function so that we can do this for the internal layers of net
             def reset_layer_params(layer):
                 if isinstance(layer, torch.nn.Linear):
                     torch.nn.init.normal_(layer.weight, mean=0., std=1 / math.sqrt(layer.out_features))
@@ -97,10 +82,6 @@ class DefaultNet(torch.nn.Module):
                     torch.nn.init.normal_(layer.mean, mean=0., std=1 / math.sqrt(layer.out_features))
                     torch.nn.init.normal_(layer.bias, mean=0., std=0.1)
 
-            if self.selfaware:
-                for layer in self.awareness_net:
-                    reset_layer_params(layer)
-
             for layer in self.net:
                 reset_layer_params(layer)
 
@@ -110,20 +91,11 @@ class DefaultNet(torch.nn.Module):
         else:
             self._foward_net = self.net
 
-        if self.selfaware:
-            self.awareness_net = self.awareness_net.to(self.device)
-            if self.available_devices > 1:
-                self._foward_awareness_net = torch.nn.DataParallel(self.awareness_net)
-            else:
-                self._foward_awareness_net = self.awareness_net
-
     def to(self, device=None, available_devices=None):
         if device is None or available_devices is None:
             device, available_devices = get_devices()
 
         self.net = self.net.to(device)
-        if self.selfaware:
-            self.awareness_net = self.awareness_net.to(device)
 
         available_devices = 1
         if 'cuda' in str(device):
@@ -131,12 +103,8 @@ class DefaultNet(torch.nn.Module):
 
         if available_devices > 1:
             self._foward_net = torch.nn.DataParallel(self.net)
-            if self.selfaware:
-                self._foward_awareness_net = torch.nn.DataParallel(self.awareness_net)
         else:
             self._foward_net = self.net
-            if self.selfaware:
-                self._foward_awareness_net = self.awareness_net
 
         self.device = device
         self.available_devices = available_devices
@@ -172,19 +140,10 @@ class DefaultNet(torch.nn.Module):
     def forward(self, input):
         """
         In this particular model, we just need to forward the network defined in setup, with our input
-
         :param input: a pytorch tensor with the input data of a batch
-        :param return_awareness: This tells if we should return the awareness output
-
-        :return: either just output or (output, awareness)
+        :return: output of the network
         """
 
         output = self._foward_net(input)
 
-        if self.selfaware:
-            interim = torch.cat((input, output), 1)
-            awareness = self._foward_awareness_net(interim)
-
-            return output, awareness
-
         return output
